# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info >= (2, 7, 0):
    def swig_import_helper():
        import importlib
        pkg = __name__.rpartition('.')[0]
        mname = '.'.join((pkg, '_VSBIOInterface')).lstrip('.')
        try:
            return importlib.import_module(mname)
        except ImportError:
            return importlib.import_module('_VSBIOInterface')
    _VSBIOInterface = swig_import_helper()
    del swig_import_helper
elif _swig_python_version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_VSBIOInterface', [dirname(__file__)])
        except ImportError:
            import _VSBIOInterface
            return _VSBIOInterface
        try:
            _mod = imp.load_module('_VSBIOInterface', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()
        return _mod
    _VSBIOInterface = swig_import_helper()
    del swig_import_helper
else:
    import _VSBIOInterface
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except __builtin__.Exception:
    class _object:
        pass
    _newclass = 0


def ReadVSBW(filename: 'wchar_t const *') -> "ReadHandle":
    return _VSBIOInterface.ReadVSBW(filename)
ReadVSBW = _VSBIOInterface.ReadVSBW

def ReadVSB(filename: 'char const *') -> "ReadHandle":
    return _VSBIOInterface.ReadVSB(filename)
ReadVSB = _VSBIOInterface.ReadVSB

def ReadNextMessage(handle: 'ReadHandle', message: 'icsSpyMessageVSB', size: 'unsigned int') -> "unsigned int *":
    return _VSBIOInterface.ReadNextMessage(handle, message, size)
ReadNextMessage = _VSBIOInterface.ReadNextMessage

def ReadClose(handle: 'ReadHandle') -> "void":
    return _VSBIOInterface.ReadClose(handle)
ReadClose = _VSBIOInterface.ReadClose

def GetProgress(handle: 'ReadHandle') -> "int":
    return _VSBIOInterface.GetProgress(handle)
GetProgress = _VSBIOInterface.GetProgress

def GetDisplayMessage(handle: 'ReadHandle') -> "char const *":
    return _VSBIOInterface.GetDisplayMessage(handle)
GetDisplayMessage = _VSBIOInterface.GetDisplayMessage

def GetErrorMessage(handle: 'ReadHandle') -> "char const *":
    return _VSBIOInterface.GetErrorMessage(handle)
GetErrorMessage = _VSBIOInterface.GetErrorMessage

def WriteVSBW(filename: 'wchar_t const *') -> "WriteHandle":
    return _VSBIOInterface.WriteVSBW(filename)
WriteVSBW = _VSBIOInterface.WriteVSBW

def WriteVSB(filename: 'char const *') -> "WriteHandle":
    return _VSBIOInterface.WriteVSB(filename)
WriteVSB = _VSBIOInterface.WriteVSB

def WriteMessage(handle: 'WriteHandle', message: 'icsSpyMessageVSB', size: 'unsigned int') -> "int":
    return _VSBIOInterface.WriteMessage(handle, message, size)
WriteMessage = _VSBIOInterface.WriteMessage

def WriteClose(handle: 'WriteHandle') -> "void":
    return _VSBIOInterface.WriteClose(handle)
WriteClose = _VSBIOInterface.WriteClose

def VSBIOFree(message: 'icsSpyMessageVSB') -> "void":
    return _VSBIOInterface.VSBIOFree(message)
VSBIOFree = _VSBIOInterface.VSBIOFree

def VSBIOMalloc(nBytes: 'int') -> "icsSpyMessageVSB *":
    return _VSBIOInterface.VSBIOMalloc(nBytes)
VSBIOMalloc = _VSBIOInterface.VSBIOMalloc
class icsSpyMessageVSB(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, icsSpyMessageVSB, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, icsSpyMessageVSB, name)
    __repr__ = _swig_repr
    __swig_setmethods__["StatusBitField"] = _VSBIOInterface.icsSpyMessageVSB_StatusBitField_set
    __swig_getmethods__["StatusBitField"] = _VSBIOInterface.icsSpyMessageVSB_StatusBitField_get
    if _newclass:
        StatusBitField = _swig_property(_VSBIOInterface.icsSpyMessageVSB_StatusBitField_get, _VSBIOInterface.icsSpyMessageVSB_StatusBitField_set)
    __swig_setmethods__["StatusBitField2"] = _VSBIOInterface.icsSpyMessageVSB_StatusBitField2_set
    __swig_getmethods__["StatusBitField2"] = _VSBIOInterface.icsSpyMessageVSB_StatusBitField2_get
    if _newclass:
        StatusBitField2 = _swig_property(_VSBIOInterface.icsSpyMessageVSB_StatusBitField2_get, _VSBIOInterface.icsSpyMessageVSB_StatusBitField2_set)
    __swig_setmethods__["TimeHardware"] = _VSBIOInterface.icsSpyMessageVSB_TimeHardware_set
    __swig_getmethods__["TimeHardware"] = _VSBIOInterface.icsSpyMessageVSB_TimeHardware_get
    if _newclass:
        TimeHardware = _swig_property(_VSBIOInterface.icsSpyMessageVSB_TimeHardware_get, _VSBIOInterface.icsSpyMessageVSB_TimeHardware_set)
    __swig_setmethods__["TimeHardware2"] = _VSBIOInterface.icsSpyMessageVSB_TimeHardware2_set
    __swig_getmethods__["TimeHardware2"] = _VSBIOInterface.icsSpyMessageVSB_TimeHardware2_get
    if _newclass:
        TimeHardware2 = _swig_property(_VSBIOInterface.icsSpyMessageVSB_TimeHardware2_get, _VSBIOInterface.icsSpyMessageVSB_TimeHardware2_set)
    __swig_setmethods__["TimeSystem"] = _VSBIOInterface.icsSpyMessageVSB_TimeSystem_set
    __swig_getmethods__["TimeSystem"] = _VSBIOInterface.icsSpyMessageVSB_TimeSystem_get
    if _newclass:
        TimeSystem = _swig_property(_VSBIOInterface.icsSpyMessageVSB_TimeSystem_get, _VSBIOInterface.icsSpyMessageVSB_TimeSystem_set)
    __swig_setmethods__["TimeSystem2"] = _VSBIOInterface.icsSpyMessageVSB_TimeSystem2_set
    __swig_getmethods__["TimeSystem2"] = _VSBIOInterface.icsSpyMessageVSB_TimeSystem2_get
    if _newclass:
        TimeSystem2 = _swig_property(_VSBIOInterface.icsSpyMessageVSB_TimeSystem2_get, _VSBIOInterface.icsSpyMessageVSB_TimeSystem2_set)
    __swig_setmethods__["TimeStampHardwareID"] = _VSBIOInterface.icsSpyMessageVSB_TimeStampHardwareID_set
    __swig_getmethods__["TimeStampHardwareID"] = _VSBIOInterface.icsSpyMessageVSB_TimeStampHardwareID_get
    if _newclass:
        TimeStampHardwareID = _swig_property(_VSBIOInterface.icsSpyMessageVSB_TimeStampHardwareID_get, _VSBIOInterface.icsSpyMessageVSB_TimeStampHardwareID_set)
    __swig_setmethods__["TimeStampSystemID"] = _VSBIOInterface.icsSpyMessageVSB_TimeStampSystemID_set
    __swig_getmethods__["TimeStampSystemID"] = _VSBIOInterface.icsSpyMessageVSB_TimeStampSystemID_get
    if _newclass:
        TimeStampSystemID = _swig_property(_VSBIOInterface.icsSpyMessageVSB_TimeStampSystemID_get, _VSBIOInterface.icsSpyMessageVSB_TimeStampSystemID_set)
    __swig_setmethods__["NetworkID"] = _VSBIOInterface.icsSpyMessageVSB_NetworkID_set
    __swig_getmethods__["NetworkID"] = _VSBIOInterface.icsSpyMessageVSB_NetworkID_get
    if _newclass:
        NetworkID = _swig_property(_VSBIOInterface.icsSpyMessageVSB_NetworkID_get, _VSBIOInterface.icsSpyMessageVSB_NetworkID_set)
    __swig_setmethods__["NodeID"] = _VSBIOInterface.icsSpyMessageVSB_NodeID_set
    __swig_getmethods__["NodeID"] = _VSBIOInterface.icsSpyMessageVSB_NodeID_get
    if _newclass:
        NodeID = _swig_property(_VSBIOInterface.icsSpyMessageVSB_NodeID_get, _VSBIOInterface.icsSpyMessageVSB_NodeID_set)
    __swig_setmethods__["Protocol"] = _VSBIOInterface.icsSpyMessageVSB_Protocol_set
    __swig_getmethods__["Protocol"] = _VSBIOInterface.icsSpyMessageVSB_Protocol_get
    if _newclass:
        Protocol = _swig_property(_VSBIOInterface.icsSpyMessageVSB_Protocol_get, _VSBIOInterface.icsSpyMessageVSB_Protocol_set)
    __swig_setmethods__["MessagePieceID"] = _VSBIOInterface.icsSpyMessageVSB_MessagePieceID_set
    __swig_getmethods__["MessagePieceID"] = _VSBIOInterface.icsSpyMessageVSB_MessagePieceID_get
    if _newclass:
        MessagePieceID = _swig_property(_VSBIOInterface.icsSpyMessageVSB_MessagePieceID_get, _VSBIOInterface.icsSpyMessageVSB_MessagePieceID_set)
    __swig_setmethods__["ExtraDataPtrEnabled"] = _VSBIOInterface.icsSpyMessageVSB_ExtraDataPtrEnabled_set
    __swig_getmethods__["ExtraDataPtrEnabled"] = _VSBIOInterface.icsSpyMessageVSB_ExtraDataPtrEnabled_get
    if _newclass:
        ExtraDataPtrEnabled = _swig_property(_VSBIOInterface.icsSpyMessageVSB_ExtraDataPtrEnabled_get, _VSBIOInterface.icsSpyMessageVSB_ExtraDataPtrEnabled_set)
    __swig_setmethods__["NumberBytesHeader"] = _VSBIOInterface.icsSpyMessageVSB_NumberBytesHeader_set
    __swig_getmethods__["NumberBytesHeader"] = _VSBIOInterface.icsSpyMessageVSB_NumberBytesHeader_get
    if _newclass:
        NumberBytesHeader = _swig_property(_VSBIOInterface.icsSpyMessageVSB_NumberBytesHeader_get, _VSBIOInterface.icsSpyMessageVSB_NumberBytesHeader_set)
    __swig_setmethods__["NumberBytesData"] = _VSBIOInterface.icsSpyMessageVSB_NumberBytesData_set
    __swig_getmethods__["NumberBytesData"] = _VSBIOInterface.icsSpyMessageVSB_NumberBytesData_get
    if _newclass:
        NumberBytesData = _swig_property(_VSBIOInterface.icsSpyMessageVSB_NumberBytesData_get, _VSBIOInterface.icsSpyMessageVSB_NumberBytesData_set)
    __swig_setmethods__["NetworkID2"] = _VSBIOInterface.icsSpyMessageVSB_NetworkID2_set
    __swig_getmethods__["NetworkID2"] = _VSBIOInterface.icsSpyMessageVSB_NetworkID2_get
    if _newclass:
        NetworkID2 = _swig_property(_VSBIOInterface.icsSpyMessageVSB_NetworkID2_get, _VSBIOInterface.icsSpyMessageVSB_NetworkID2_set)
    __swig_setmethods__["DescriptionID"] = _VSBIOInterface.icsSpyMessageVSB_DescriptionID_set
    __swig_getmethods__["DescriptionID"] = _VSBIOInterface.icsSpyMessageVSB_DescriptionID_get
    if _newclass:
        DescriptionID = _swig_property(_VSBIOInterface.icsSpyMessageVSB_DescriptionID_get, _VSBIOInterface.icsSpyMessageVSB_DescriptionID_set)
    __swig_setmethods__["ArbIDOrHeader"] = _VSBIOInterface.icsSpyMessageVSB_ArbIDOrHeader_set
    __swig_getmethods__["ArbIDOrHeader"] = _VSBIOInterface.icsSpyMessageVSB_ArbIDOrHeader_get
    if _newclass:
        ArbIDOrHeader = _swig_property(_VSBIOInterface.icsSpyMessageVSB_ArbIDOrHeader_get, _VSBIOInterface.icsSpyMessageVSB_ArbIDOrHeader_set)
    __swig_setmethods__["Data"] = _VSBIOInterface.icsSpyMessageVSB_Data_set
    __swig_getmethods__["Data"] = _VSBIOInterface.icsSpyMessageVSB_Data_get
    if _newclass:
        Data = _swig_property(_VSBIOInterface.icsSpyMessageVSB_Data_get, _VSBIOInterface.icsSpyMessageVSB_Data_set)
    __swig_setmethods__["StatusBitField3"] = _VSBIOInterface.icsSpyMessageVSB_StatusBitField3_set
    __swig_getmethods__["StatusBitField3"] = _VSBIOInterface.icsSpyMessageVSB_StatusBitField3_get
    if _newclass:
        StatusBitField3 = _swig_property(_VSBIOInterface.icsSpyMessageVSB_StatusBitField3_get, _VSBIOInterface.icsSpyMessageVSB_StatusBitField3_set)
    __swig_setmethods__["StatusBitField4"] = _VSBIOInterface.icsSpyMessageVSB_StatusBitField4_set
    __swig_getmethods__["StatusBitField4"] = _VSBIOInterface.icsSpyMessageVSB_StatusBitField4_get
    if _newclass:
        StatusBitField4 = _swig_property(_VSBIOInterface.icsSpyMessageVSB_StatusBitField4_get, _VSBIOInterface.icsSpyMessageVSB_StatusBitField4_set)
    __swig_setmethods__["AckBytes"] = _VSBIOInterface.icsSpyMessageVSB_AckBytes_set
    __swig_getmethods__["AckBytes"] = _VSBIOInterface.icsSpyMessageVSB_AckBytes_get
    if _newclass:
        AckBytes = _swig_property(_VSBIOInterface.icsSpyMessageVSB_AckBytes_get, _VSBIOInterface.icsSpyMessageVSB_AckBytes_set)
    __swig_setmethods__["ExtraDataPtr"] = _VSBIOInterface.icsSpyMessageVSB_ExtraDataPtr_set
    __swig_getmethods__["ExtraDataPtr"] = _VSBIOInterface.icsSpyMessageVSB_ExtraDataPtr_get
    if _newclass:
        ExtraDataPtr = _swig_property(_VSBIOInterface.icsSpyMessageVSB_ExtraDataPtr_get, _VSBIOInterface.icsSpyMessageVSB_ExtraDataPtr_set)
    __swig_setmethods__["MiscData"] = _VSBIOInterface.icsSpyMessageVSB_MiscData_set
    __swig_getmethods__["MiscData"] = _VSBIOInterface.icsSpyMessageVSB_MiscData_get
    if _newclass:
        MiscData = _swig_property(_VSBIOInterface.icsSpyMessageVSB_MiscData_get, _VSBIOInterface.icsSpyMessageVSB_MiscData_set)
    __swig_setmethods__["Reserved"] = _VSBIOInterface.icsSpyMessageVSB_Reserved_set
    __swig_getmethods__["Reserved"] = _VSBIOInterface.icsSpyMessageVSB_Reserved_get
    if _newclass:
        Reserved = _swig_property(_VSBIOInterface.icsSpyMessageVSB_Reserved_get, _VSBIOInterface.icsSpyMessageVSB_Reserved_set)

    def __init__(self):
        this = _VSBIOInterface.new_icsSpyMessageVSB()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _VSBIOInterface.delete_icsSpyMessageVSB
    __del__ = lambda self: None
icsSpyMessageVSB_swigregister = _VSBIOInterface.icsSpyMessageVSB_swigregister
icsSpyMessageVSB_swigregister(icsSpyMessageVSB)

icsSpyMessageVSB_SIZE = _VSBIOInterface.icsSpyMessageVSB_SIZE
eSuccess = _VSBIOInterface.eSuccess
eEndOfFile = _VSBIOInterface.eEndOfFile
eError = _VSBIOInterface.eError
eBufferToSmall = _VSBIOInterface.eBufferToSmall

def GetEDP(message: 'icsSpyMessageVSB') -> "char *":
    return _VSBIOInterface.GetEDP(message)
GetEDP = _VSBIOInterface.GetEDP

def GetByteFromData(message: 'icsSpyMessageVSB', index: 'size_t') -> "unsigned char":
    return _VSBIOInterface.GetByteFromData(message, index)
GetByteFromData = _VSBIOInterface.GetByteFromData
class intArray8(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, intArray8, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, intArray8, name)
    __repr__ = _swig_repr
    __swig_setmethods__["data"] = _VSBIOInterface.intArray8_data_set
    __swig_getmethods__["data"] = _VSBIOInterface.intArray8_data_get
    if _newclass:
        data = _swig_property(_VSBIOInterface.intArray8_data_get, _VSBIOInterface.intArray8_data_set)

    def __len__(self) -> "size_t":
        return _VSBIOInterface.intArray8___len__(self)

    def __getitem__(self, i: 'size_t') -> "unsigned char const &":
        return _VSBIOInterface.intArray8___getitem__(self, i)

    def __setitem__(self, i: 'size_t', v: 'unsigned char const &') -> "void":
        return _VSBIOInterface.intArray8___setitem__(self, i, v)

    def __init__(self):
        this = _VSBIOInterface.new_intArray8()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _VSBIOInterface.delete_intArray8
    __del__ = lambda self: None
intArray8_swigregister = _VSBIOInterface.intArray8_swigregister
intArray8_swigregister(intArray8)

class intArray3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, intArray3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, intArray3, name)
    __repr__ = _swig_repr
    __swig_setmethods__["data"] = _VSBIOInterface.intArray3_data_set
    __swig_getmethods__["data"] = _VSBIOInterface.intArray3_data_get
    if _newclass:
        data = _swig_property(_VSBIOInterface.intArray3_data_get, _VSBIOInterface.intArray3_data_set)

    def __len__(self) -> "size_t":
        return _VSBIOInterface.intArray3___len__(self)

    def __getitem__(self, i: 'size_t') -> "unsigned char const &":
        return _VSBIOInterface.intArray3___getitem__(self, i)

    def __setitem__(self, i: 'size_t', v: 'unsigned char const &') -> "void":
        return _VSBIOInterface.intArray3___setitem__(self, i, v)

    def __init__(self):
        this = _VSBIOInterface.new_intArray3()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _VSBIOInterface.delete_intArray3
    __del__ = lambda self: None
intArray3_swigregister = _VSBIOInterface.intArray3_swigregister
intArray3_swigregister(intArray3)

# This file is compatible with both classic and new-style classes.





# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info >= (2, 7, 0):
    def swig_import_helper():
        import importlib
        pkg = __name__.rpartition('.')[0]
        mname = '.'.join((pkg, '_VSBIOFlags')).lstrip('.')
        try:
            return importlib.import_module(mname)
        except ImportError:
            return importlib.import_module('_VSBIOFlags')
    _VSBIOFlags = swig_import_helper()
    del swig_import_helper
elif _swig_python_version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_VSBIOFlags', [dirname(__file__)])
        except ImportError:
            import _VSBIOFlags
            return _VSBIOFlags
        try:
            _mod = imp.load_module('_VSBIOFlags', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()
        return _mod
    _VSBIOFlags = swig_import_helper()
    del swig_import_helper
else:
    import _VSBIOFlags
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except __builtin__.Exception:
    class _object:
        pass
    _newclass = 0

NEOVI_COMMTYPE_RS232 = _VSBIOFlags.NEOVI_COMMTYPE_RS232
NEOVI_COMMTYPE_USB_BULK = _VSBIOFlags.NEOVI_COMMTYPE_USB_BULK
NEOVI_COMMTYPE_TCPIP = _VSBIOFlags.NEOVI_COMMTYPE_TCPIP
NEOVI_COMMTYPE_FIRE_USB = _VSBIOFlags.NEOVI_COMMTYPE_FIRE_USB
NETID_DEVICE = _VSBIOFlags.NETID_DEVICE
NETID_HSCAN = _VSBIOFlags.NETID_HSCAN
NETID_MSCAN = _VSBIOFlags.NETID_MSCAN
NETID_SWCAN = _VSBIOFlags.NETID_SWCAN
NETID_LSFTCAN = _VSBIOFlags.NETID_LSFTCAN
NETID_FORDSCP = _VSBIOFlags.NETID_FORDSCP
NETID_J1708 = _VSBIOFlags.NETID_J1708
NETID_AUX = _VSBIOFlags.NETID_AUX
NETID_JVPW = _VSBIOFlags.NETID_JVPW
NETID_ISO = _VSBIOFlags.NETID_ISO
NETID_ISOPIC = _VSBIOFlags.NETID_ISOPIC
NETID_MAIN51 = _VSBIOFlags.NETID_MAIN51
NETID_RED = _VSBIOFlags.NETID_RED
NETID_SCI = _VSBIOFlags.NETID_SCI
NETID_ISO2 = _VSBIOFlags.NETID_ISO2
NETID_ISO14230 = _VSBIOFlags.NETID_ISO14230
NETID_LIN = _VSBIOFlags.NETID_LIN
NETID_OP_ETHERNET1 = _VSBIOFlags.NETID_OP_ETHERNET1
NETID_OP_ETHERNET2 = _VSBIOFlags.NETID_OP_ETHERNET2
NETID_OP_ETHERNET3 = _VSBIOFlags.NETID_OP_ETHERNET3
NETID_ISO3 = _VSBIOFlags.NETID_ISO3
NETID_HSCAN2 = _VSBIOFlags.NETID_HSCAN2
NETID_HSCAN3 = _VSBIOFlags.NETID_HSCAN3
NETID_OP_ETHERNET4 = _VSBIOFlags.NETID_OP_ETHERNET4
NETID_OP_ETHERNET5 = _VSBIOFlags.NETID_OP_ETHERNET5
NETID_ISO4 = _VSBIOFlags.NETID_ISO4
NETID_LIN2 = _VSBIOFlags.NETID_LIN2
NETID_LIN3 = _VSBIOFlags.NETID_LIN3
NETID_LIN4 = _VSBIOFlags.NETID_LIN4
NETID_MOST = _VSBIOFlags.NETID_MOST
NETID_RED_APP_ERROR = _VSBIOFlags.NETID_RED_APP_ERROR
NETID_CGI = _VSBIOFlags.NETID_CGI
NETID_3G_RESET_STATUS = _VSBIOFlags.NETID_3G_RESET_STATUS
NETID_3G_FB_STATUS = _VSBIOFlags.NETID_3G_FB_STATUS
NETID_3G_APP_SIGNAL_STATUS = _VSBIOFlags.NETID_3G_APP_SIGNAL_STATUS
NETID_3G_READ_DATALINK_CM_TX_MSG = _VSBIOFlags.NETID_3G_READ_DATALINK_CM_TX_MSG
NETID_3G_READ_DATALINK_CM_RX_MSG = _VSBIOFlags.NETID_3G_READ_DATALINK_CM_RX_MSG
NETID_3G_LOGGING_OVERFLOW = _VSBIOFlags.NETID_3G_LOGGING_OVERFLOW
NETID_3G_READ_SETTINGS_EX = _VSBIOFlags.NETID_3G_READ_SETTINGS_EX
NETID_HSCAN4 = _VSBIOFlags.NETID_HSCAN4
NETID_HSCAN5 = _VSBIOFlags.NETID_HSCAN5
NETID_RS232 = _VSBIOFlags.NETID_RS232
NETID_UART = _VSBIOFlags.NETID_UART
NETID_UART2 = _VSBIOFlags.NETID_UART2
NETID_UART3 = _VSBIOFlags.NETID_UART3
NETID_UART4 = _VSBIOFlags.NETID_UART4
NETID_SWCAN2 = _VSBIOFlags.NETID_SWCAN2
NETID_ETHERNET_DAQ = _VSBIOFlags.NETID_ETHERNET_DAQ
NETID_DATA_TO_HOST = _VSBIOFlags.NETID_DATA_TO_HOST
NETID_TEXTAPI_TO_HOST = _VSBIOFlags.NETID_TEXTAPI_TO_HOST
NETID_I2C1 = _VSBIOFlags.NETID_I2C1
NETID_SPI1 = _VSBIOFlags.NETID_SPI1
NETID_OP_ETHERNET6 = _VSBIOFlags.NETID_OP_ETHERNET6
NETID_RED_VBAT = _VSBIOFlags.NETID_RED_VBAT
NETID_OP_ETHERNET7 = _VSBIOFlags.NETID_OP_ETHERNET7
NETID_OP_ETHERNET8 = _VSBIOFlags.NETID_OP_ETHERNET8
NETID_OP_ETHERNET9 = _VSBIOFlags.NETID_OP_ETHERNET9
NETID_OP_ETHERNET10 = _VSBIOFlags.NETID_OP_ETHERNET10
NETID_OP_ETHERNET11 = _VSBIOFlags.NETID_OP_ETHERNET11
NETID_FLEXRAY1A = _VSBIOFlags.NETID_FLEXRAY1A
NETID_FLEXRAY1B = _VSBIOFlags.NETID_FLEXRAY1B
NETID_FLEXRAY2A = _VSBIOFlags.NETID_FLEXRAY2A
NETID_FLEXRAY2B = _VSBIOFlags.NETID_FLEXRAY2B
NETID_LIN5 = _VSBIOFlags.NETID_LIN5
NETID_FLEXRAY = _VSBIOFlags.NETID_FLEXRAY
NETID_FLEXRAY2 = _VSBIOFlags.NETID_FLEXRAY2
NETID_OP_ETHERNET12 = _VSBIOFlags.NETID_OP_ETHERNET12
NETID_MOST25 = _VSBIOFlags.NETID_MOST25
NETID_MOST50 = _VSBIOFlags.NETID_MOST50
NETID_MOST150 = _VSBIOFlags.NETID_MOST150
NETID_ETHERNET = _VSBIOFlags.NETID_ETHERNET
NETID_GMFSA = _VSBIOFlags.NETID_GMFSA
NETID_TCP = _VSBIOFlags.NETID_TCP
NETID_HSCAN6 = _VSBIOFlags.NETID_HSCAN6
NETID_HSCAN7 = _VSBIOFlags.NETID_HSCAN7
NETID_LIN6 = _VSBIOFlags.NETID_LIN6
NETID_LSFTCAN2 = _VSBIOFlags.NETID_LSFTCAN2
NETID_HW_COM_LATENCY_TEST = _VSBIOFlags.NETID_HW_COM_LATENCY_TEST
NETID_DEVICE_STATUS = _VSBIOFlags.NETID_DEVICE_STATUS
NETID_MAX = _VSBIOFlags.NETID_MAX
NETID_INVALID = _VSBIOFlags.NETID_INVALID
NEODEVICE_UNKNOWN = _VSBIOFlags.NEODEVICE_UNKNOWN
NEODEVICE_BLUE = _VSBIOFlags.NEODEVICE_BLUE
NEODEVICE_ECU_AVB = _VSBIOFlags.NEODEVICE_ECU_AVB
NEODEVICE_RADSUPERMOON = _VSBIOFlags.NEODEVICE_RADSUPERMOON
NEODEVICE_DW_VCAN = _VSBIOFlags.NEODEVICE_DW_VCAN
NEODEVICE_RADMOON2 = _VSBIOFlags.NEODEVICE_RADMOON2
NEODEVICE_RADGIGALOG = _VSBIOFlags.NEODEVICE_RADGIGALOG
NEODEVICE_VCAN41 = _VSBIOFlags.NEODEVICE_VCAN41
NEODEVICE_FIRE = _VSBIOFlags.NEODEVICE_FIRE
NEODEVICE_VCAN3 = _VSBIOFlags.NEODEVICE_VCAN3
NEODEVICE_RED = _VSBIOFlags.NEODEVICE_RED
NEODEVICE_ECU = _VSBIOFlags.NEODEVICE_ECU
NEODEVICE_IEVB = _VSBIOFlags.NEODEVICE_IEVB
NEODEVICE_PENDANT = _VSBIOFlags.NEODEVICE_PENDANT
NEODEVICE_OBD2_PRO = _VSBIOFlags.NEODEVICE_OBD2_PRO
NEODEVICE_ECUCHIP_UART = _VSBIOFlags.NEODEVICE_ECUCHIP_UART
NEODEVICE_PLASMA = _VSBIOFlags.NEODEVICE_PLASMA
NEODEVICE_DONT_REUSE0 = _VSBIOFlags.NEODEVICE_DONT_REUSE0
NEODEVICE_NEOANALOG = _VSBIOFlags.NEODEVICE_NEOANALOG
NEODEVICE_CT_OBD = _VSBIOFlags.NEODEVICE_CT_OBD
NEODEVICE_DONT_REUSE1 = _VSBIOFlags.NEODEVICE_DONT_REUSE1
NEODEVICE_DONT_REUSE2 = _VSBIOFlags.NEODEVICE_DONT_REUSE2
NEODEVICE_ION = _VSBIOFlags.NEODEVICE_ION
NEODEVICE_RADSTAR = _VSBIOFlags.NEODEVICE_RADSTAR
NEODEVICE_DONT_REUSE3 = _VSBIOFlags.NEODEVICE_DONT_REUSE3
NEODEVICE_VCAN4 = _VSBIOFlags.NEODEVICE_VCAN4
NEODEVICE_VCAN42 = _VSBIOFlags.NEODEVICE_VCAN42
NEODEVICE_CMPROBE = _VSBIOFlags.NEODEVICE_CMPROBE
NEODEVICE_EEVB = _VSBIOFlags.NEODEVICE_EEVB
NEODEVICE_VCANRF = _VSBIOFlags.NEODEVICE_VCANRF
NEODEVICE_FIRE2 = _VSBIOFlags.NEODEVICE_FIRE2
NEODEVICE_FLEX = _VSBIOFlags.NEODEVICE_FLEX
NEODEVICE_RADGALAXY = _VSBIOFlags.NEODEVICE_RADGALAXY
NEODEVICE_RADSTAR2 = _VSBIOFlags.NEODEVICE_RADSTAR2
NEODEVICE_VIVIDCAN = _VSBIOFlags.NEODEVICE_VIVIDCAN
NEODEVICE_OBD2_SIM = _VSBIOFlags.NEODEVICE_OBD2_SIM
NEODEVICE_ANY_PLASMA = _VSBIOFlags.NEODEVICE_ANY_PLASMA
NEODEVICE_ANY_ION = _VSBIOFlags.NEODEVICE_ANY_ION
NEODEVICE_NEOECUCHIP = _VSBIOFlags.NEODEVICE_NEOECUCHIP
ISO15765_2_NETWORK_HSCAN = _VSBIOFlags.ISO15765_2_NETWORK_HSCAN
ISO15765_2_NETWORK_MSCAN = _VSBIOFlags.ISO15765_2_NETWORK_MSCAN
ISO15765_2_NETWORK_HSCAN2 = _VSBIOFlags.ISO15765_2_NETWORK_HSCAN2
ISO15765_2_NETWORK_HSCAN3 = _VSBIOFlags.ISO15765_2_NETWORK_HSCAN3
ISO15765_2_NETWORK_SWCAN = _VSBIOFlags.ISO15765_2_NETWORK_SWCAN
ISO15765_2_NETWORK_HSCAN4 = _VSBIOFlags.ISO15765_2_NETWORK_HSCAN4
ISO15765_2_NETWORK_HSCAN5 = _VSBIOFlags.ISO15765_2_NETWORK_HSCAN5
ISO15765_2_NETWORK_HSCAN6 = _VSBIOFlags.ISO15765_2_NETWORK_HSCAN6
ISO15765_2_NETWORK_HSCAN7 = _VSBIOFlags.ISO15765_2_NETWORK_HSCAN7
ISO15765_2_NETWORK_SWCAN2 = _VSBIOFlags.ISO15765_2_NETWORK_SWCAN2
PLASMA_SLAVE1_OFFSET = _VSBIOFlags.PLASMA_SLAVE1_OFFSET
PLASMA_SLAVE2_OFFSET = _VSBIOFlags.PLASMA_SLAVE2_OFFSET
PLASMA_SLAVE_NUM = _VSBIOFlags.PLASMA_SLAVE_NUM
PLASMA_SLAVE1_OFFSET_RANGE2 = _VSBIOFlags.PLASMA_SLAVE1_OFFSET_RANGE2
PLASMA_SLAVE2_OFFSET_RANGE2 = _VSBIOFlags.PLASMA_SLAVE2_OFFSET_RANGE2
PLASMA_SLAVE3_OFFSET_RANGE2 = _VSBIOFlags.PLASMA_SLAVE3_OFFSET_RANGE2
SCRIPT_STATUS_STOPPED = _VSBIOFlags.SCRIPT_STATUS_STOPPED
SCRIPT_STATUS_RUNNING = _VSBIOFlags.SCRIPT_STATUS_RUNNING
SCRIPT_LOCATION_FLASH_MEM = _VSBIOFlags.SCRIPT_LOCATION_FLASH_MEM
SCRIPT_LOCATION_INTERNAL_FLASH = _VSBIOFlags.SCRIPT_LOCATION_INTERNAL_FLASH
SCRIPT_LOCATION_SDCARD = _VSBIOFlags.SCRIPT_LOCATION_SDCARD
SCRIPT_LOCATION_VCAN3_MEM = _VSBIOFlags.SCRIPT_LOCATION_VCAN3_MEM
SPY_PROTOCOL_CUSTOM = _VSBIOFlags.SPY_PROTOCOL_CUSTOM
SPY_PROTOCOL_CAN = _VSBIOFlags.SPY_PROTOCOL_CAN
SPY_PROTOCOL_GMLAN = _VSBIOFlags.SPY_PROTOCOL_GMLAN
SPY_PROTOCOL_J1850VPW = _VSBIOFlags.SPY_PROTOCOL_J1850VPW
SPY_PROTOCOL_J1850PWM = _VSBIOFlags.SPY_PROTOCOL_J1850PWM
SPY_PROTOCOL_ISO9141 = _VSBIOFlags.SPY_PROTOCOL_ISO9141
SPY_PROTOCOL_Keyword2000 = _VSBIOFlags.SPY_PROTOCOL_Keyword2000
SPY_PROTOCOL_GM_ALDL_UART = _VSBIOFlags.SPY_PROTOCOL_GM_ALDL_UART
SPY_PROTOCOL_CHRYSLER_CCD = _VSBIOFlags.SPY_PROTOCOL_CHRYSLER_CCD
SPY_PROTOCOL_CHRYSLER_SCI = _VSBIOFlags.SPY_PROTOCOL_CHRYSLER_SCI
SPY_PROTOCOL_FORD_UBP = _VSBIOFlags.SPY_PROTOCOL_FORD_UBP
SPY_PROTOCOL_BEAN = _VSBIOFlags.SPY_PROTOCOL_BEAN
SPY_PROTOCOL_LIN = _VSBIOFlags.SPY_PROTOCOL_LIN
SPY_PROTOCOL_J1708 = _VSBIOFlags.SPY_PROTOCOL_J1708
SPY_PROTOCOL_CHRYSLER_JVPW = _VSBIOFlags.SPY_PROTOCOL_CHRYSLER_JVPW
SPY_PROTOCOL_J1939 = _VSBIOFlags.SPY_PROTOCOL_J1939
SPY_PROTOCOL_FLEXRAY = _VSBIOFlags.SPY_PROTOCOL_FLEXRAY
SPY_PROTOCOL_MOST = _VSBIOFlags.SPY_PROTOCOL_MOST
SPY_PROTOCOL_CGI = _VSBIOFlags.SPY_PROTOCOL_CGI
SPY_PROTOCOL_GME_CIM_SCL_KLINE = _VSBIOFlags.SPY_PROTOCOL_GME_CIM_SCL_KLINE
SPY_PROTOCOL_SPI = _VSBIOFlags.SPY_PROTOCOL_SPI
SPY_PROTOCOL_I2C = _VSBIOFlags.SPY_PROTOCOL_I2C
SPY_PROTOCOL_GENERIC_UART = _VSBIOFlags.SPY_PROTOCOL_GENERIC_UART
SPY_PROTOCOL_JTAG = _VSBIOFlags.SPY_PROTOCOL_JTAG
SPY_PROTOCOL_UNIO = _VSBIOFlags.SPY_PROTOCOL_UNIO
SPY_PROTOCOL_DALLAS_1WIRE = _VSBIOFlags.SPY_PROTOCOL_DALLAS_1WIRE
SPY_PROTOCOL_GENERIC_MANCHSESTER = _VSBIOFlags.SPY_PROTOCOL_GENERIC_MANCHSESTER
SPY_PROTOCOL_SENT_PROTOCOL = _VSBIOFlags.SPY_PROTOCOL_SENT_PROTOCOL
SPY_PROTOCOL_UART = _VSBIOFlags.SPY_PROTOCOL_UART
SPY_PROTOCOL_ETHERNET = _VSBIOFlags.SPY_PROTOCOL_ETHERNET
SPY_PROTOCOL_CANFD = _VSBIOFlags.SPY_PROTOCOL_CANFD
SPY_PROTOCOL_GMFSA = _VSBIOFlags.SPY_PROTOCOL_GMFSA
SPY_PROTOCOL_TCP = _VSBIOFlags.SPY_PROTOCOL_TCP
SPY_STATUS_GLOBAL_ERR = _VSBIOFlags.SPY_STATUS_GLOBAL_ERR
SPY_STATUS_TX_MSG = _VSBIOFlags.SPY_STATUS_TX_MSG
SPY_STATUS_XTD_FRAME = _VSBIOFlags.SPY_STATUS_XTD_FRAME
SPY_STATUS_REMOTE_FRAME = _VSBIOFlags.SPY_STATUS_REMOTE_FRAME
SPY_STATUS_CRC_ERROR = _VSBIOFlags.SPY_STATUS_CRC_ERROR
SPY_STATUS_CAN_ERROR_PASSIVE = _VSBIOFlags.SPY_STATUS_CAN_ERROR_PASSIVE
SPY_STATUS_HEADERCRC_ERROR = _VSBIOFlags.SPY_STATUS_HEADERCRC_ERROR
SPY_STATUS_INCOMPLETE_FRAME = _VSBIOFlags.SPY_STATUS_INCOMPLETE_FRAME
SPY_STATUS_LOST_ARBITRATION = _VSBIOFlags.SPY_STATUS_LOST_ARBITRATION
SPY_STATUS_UNDEFINED_ERROR = _VSBIOFlags.SPY_STATUS_UNDEFINED_ERROR
SPY_STATUS_CAN_BUS_OFF = _VSBIOFlags.SPY_STATUS_CAN_BUS_OFF
SPY_STATUS_BUS_RECOVERED = _VSBIOFlags.SPY_STATUS_BUS_RECOVERED
SPY_STATUS_BUS_SHORTED_PLUS = _VSBIOFlags.SPY_STATUS_BUS_SHORTED_PLUS
SPY_STATUS_BUS_SHORTED_GND = _VSBIOFlags.SPY_STATUS_BUS_SHORTED_GND
SPY_STATUS_CHECKSUM_ERROR = _VSBIOFlags.SPY_STATUS_CHECKSUM_ERROR
SPY_STATUS_BAD_MESSAGE_BIT_TIME_ERROR = _VSBIOFlags.SPY_STATUS_BAD_MESSAGE_BIT_TIME_ERROR
SPY_STATUS_TX_NOMATCH = _VSBIOFlags.SPY_STATUS_TX_NOMATCH
SPY_STATUS_COMM_IN_OVERFLOW = _VSBIOFlags.SPY_STATUS_COMM_IN_OVERFLOW
SPY_STATUS_EXPECTED_LEN_MISMATCH = _VSBIOFlags.SPY_STATUS_EXPECTED_LEN_MISMATCH
SPY_STATUS_MSG_NO_MATCH = _VSBIOFlags.SPY_STATUS_MSG_NO_MATCH
SPY_STATUS_BREAK = _VSBIOFlags.SPY_STATUS_BREAK
SPY_STATUS_AVSI_REC_OVERFLOW = _VSBIOFlags.SPY_STATUS_AVSI_REC_OVERFLOW
SPY_STATUS_TEST_TRIGGER = _VSBIOFlags.SPY_STATUS_TEST_TRIGGER
SPY_STATUS_AUDIO_COMMENT = _VSBIOFlags.SPY_STATUS_AUDIO_COMMENT
SPY_STATUS_GPS_DATA = _VSBIOFlags.SPY_STATUS_GPS_DATA
SPY_STATUS_ANALOG_DIGITAL_INPUT = _VSBIOFlags.SPY_STATUS_ANALOG_DIGITAL_INPUT
SPY_STATUS_TEXT_COMMENT = _VSBIOFlags.SPY_STATUS_TEXT_COMMENT
SPY_STATUS_NETWORK_MESSAGE_TYPE = _VSBIOFlags.SPY_STATUS_NETWORK_MESSAGE_TYPE
SPY_STATUS_VSI_TX_UNDERRUN = _VSBIOFlags.SPY_STATUS_VSI_TX_UNDERRUN
SPY_STATUS_VSI_IFR_CRC_BIT = _VSBIOFlags.SPY_STATUS_VSI_IFR_CRC_BIT
SPY_STATUS_INIT_MESSAGE = _VSBIOFlags.SPY_STATUS_INIT_MESSAGE
SPY_STATUS_LIN_MASTER = _VSBIOFlags.SPY_STATUS_LIN_MASTER
SPY_STATUS_CANFD = _VSBIOFlags.SPY_STATUS_CANFD
SPY_STATUS_PDU = _VSBIOFlags.SPY_STATUS_PDU
SPY_STATUS_FLEXRAY_PDU = _VSBIOFlags.SPY_STATUS_FLEXRAY_PDU
SPY_STATUS_HIGH_SPEED = _VSBIOFlags.SPY_STATUS_HIGH_SPEED
SPY_STATUS_EXTENDED = _VSBIOFlags.SPY_STATUS_EXTENDED
SPY_STATUS_FLEXRAY_PDU_UPDATE_BIT_SET = _VSBIOFlags.SPY_STATUS_FLEXRAY_PDU_UPDATE_BIT_SET
SPY_STATUS_FLEXRAY_PDU_NO_UPDATE_BIT = _VSBIOFlags.SPY_STATUS_FLEXRAY_PDU_NO_UPDATE_BIT
SPY_STATUS2_HAS_VALUE = _VSBIOFlags.SPY_STATUS2_HAS_VALUE
SPY_STATUS2_VALUE_IS_BOOLEAN = _VSBIOFlags.SPY_STATUS2_VALUE_IS_BOOLEAN
SPY_STATUS2_HIGH_VOLTAGE = _VSBIOFlags.SPY_STATUS2_HIGH_VOLTAGE
SPY_STATUS2_LONG_MESSAGE = _VSBIOFlags.SPY_STATUS2_LONG_MESSAGE
SPY_STATUS2_GLOBAL_CHANGE = _VSBIOFlags.SPY_STATUS2_GLOBAL_CHANGE
SPY_STATUS2_ERROR_FRAME = _VSBIOFlags.SPY_STATUS2_ERROR_FRAME
SPY_STATUS2_END_OF_LONG_MESSAGE = _VSBIOFlags.SPY_STATUS2_END_OF_LONG_MESSAGE
SPY_STATUS2_LIN_ERR_RX_BREAK_NOT_0 = _VSBIOFlags.SPY_STATUS2_LIN_ERR_RX_BREAK_NOT_0
SPY_STATUS2_LIN_ERR_RX_BREAK_TOO_SHORT = _VSBIOFlags.SPY_STATUS2_LIN_ERR_RX_BREAK_TOO_SHORT
SPY_STATUS2_LIN_ERR_RX_SYNC_NOT_55 = _VSBIOFlags.SPY_STATUS2_LIN_ERR_RX_SYNC_NOT_55
SPY_STATUS2_LIN_ERR_RX_DATA_GREATER_8 = _VSBIOFlags.SPY_STATUS2_LIN_ERR_RX_DATA_GREATER_8
SPY_STATUS2_LIN_ERR_TX_RX_MISMATCH = _VSBIOFlags.SPY_STATUS2_LIN_ERR_TX_RX_MISMATCH
SPY_STATUS2_LIN_ERR_MSG_ID_PARITY = _VSBIOFlags.SPY_STATUS2_LIN_ERR_MSG_ID_PARITY
SPY_STATUS2_ISO_FRAME_ERROR = _VSBIOFlags.SPY_STATUS2_ISO_FRAME_ERROR
SPY_STATUS2_LIN_SYNC_FRAME_ERROR = _VSBIOFlags.SPY_STATUS2_LIN_SYNC_FRAME_ERROR
SPY_STATUS2_ISO_OVERFLOW_ERROR = _VSBIOFlags.SPY_STATUS2_ISO_OVERFLOW_ERROR
SPY_STATUS2_LIN_ID_FRAME_ERROR = _VSBIOFlags.SPY_STATUS2_LIN_ID_FRAME_ERROR
SPY_STATUS2_ISO_PARITY_ERROR = _VSBIOFlags.SPY_STATUS2_ISO_PARITY_ERROR
SPY_STATUS2_LIN_SLAVE_BYTE_ERROR = _VSBIOFlags.SPY_STATUS2_LIN_SLAVE_BYTE_ERROR
SPY_STATUS2_RX_TIMEOUT_ERROR = _VSBIOFlags.SPY_STATUS2_RX_TIMEOUT_ERROR
SPY_STATUS2_LIN_NO_SLAVE_DATA = _VSBIOFlags.SPY_STATUS2_LIN_NO_SLAVE_DATA
SPY_STATUS3_LIN_JUST_BREAK_SYNC = _VSBIOFlags.SPY_STATUS3_LIN_JUST_BREAK_SYNC
SPY_STATUS3_LIN_SLAVE_DATA_TOO_SHORT = _VSBIOFlags.SPY_STATUS3_LIN_SLAVE_DATA_TOO_SHORT
SPY_STATUS3_LIN_ONLY_UPDATE_SLAVE_TABLE_ONCE = _VSBIOFlags.SPY_STATUS3_LIN_ONLY_UPDATE_SLAVE_TABLE_ONCE
SPY_STATUS2_MOST_PACKET_DATA = _VSBIOFlags.SPY_STATUS2_MOST_PACKET_DATA
SPY_STATUS2_MOST_STATUS = _VSBIOFlags.SPY_STATUS2_MOST_STATUS
SPY_STATUS2_MOST_LOW_LEVEL = _VSBIOFlags.SPY_STATUS2_MOST_LOW_LEVEL
SPY_STATUS2_MOST_CONTROL_DATA = _VSBIOFlags.SPY_STATUS2_MOST_CONTROL_DATA
SPY_STATUS2_MOST_MHP_USER_DATA = _VSBIOFlags.SPY_STATUS2_MOST_MHP_USER_DATA
SPY_STATUS2_MOST_MHP_CONTROL_DATA = _VSBIOFlags.SPY_STATUS2_MOST_MHP_CONTROL_DATA
SPY_STATUS2_MOST_I2S_DUMP = _VSBIOFlags.SPY_STATUS2_MOST_I2S_DUMP
SPY_STATUS2_MOST_TOO_SHORT = _VSBIOFlags.SPY_STATUS2_MOST_TOO_SHORT
SPY_STATUS2_MOST_MOST50 = _VSBIOFlags.SPY_STATUS2_MOST_MOST50
SPY_STATUS2_MOST_MOST150 = _VSBIOFlags.SPY_STATUS2_MOST_MOST150
SPY_STATUS2_MOST_CHANGED_PAR = _VSBIOFlags.SPY_STATUS2_MOST_CHANGED_PAR
SPY_STATUS2_ETHERNET_CRC_ERROR = _VSBIOFlags.SPY_STATUS2_ETHERNET_CRC_ERROR
SPY_STATUS2_ETHERNET_FRAME_TOO_SHORT = _VSBIOFlags.SPY_STATUS2_ETHERNET_FRAME_TOO_SHORT
SPY_STATUS2_ETHERNET_FCS_AVAILABLE = _VSBIOFlags.SPY_STATUS2_ETHERNET_FCS_AVAILABLE
SPY_STATUS2_ETHERNET_NO_PADDING = _VSBIOFlags.SPY_STATUS2_ETHERNET_NO_PADDING
SPY_STATUS2_ETHERNET_PREEMPTION_ENABLED = _VSBIOFlags.SPY_STATUS2_ETHERNET_PREEMPTION_ENABLED
SPY_STATUS2_FLEXRAY_TX_AB = _VSBIOFlags.SPY_STATUS2_FLEXRAY_TX_AB
SPY_STATUS2_FLEXRAY_TX_AB_NO_A = _VSBIOFlags.SPY_STATUS2_FLEXRAY_TX_AB_NO_A
SPY_STATUS2_FLEXRAY_TX_AB_NO_B = _VSBIOFlags.SPY_STATUS2_FLEXRAY_TX_AB_NO_B
SPY_STATUS2_FLEXRAY_TX_AB_NO_MATCH = _VSBIOFlags.SPY_STATUS2_FLEXRAY_TX_AB_NO_MATCH
SPY_STATUS2_FLEXRAY_NO_CRC = _VSBIOFlags.SPY_STATUS2_FLEXRAY_NO_CRC
SPY_STATUS2_FLEXRAY_NO_HEADERCRC = _VSBIOFlags.SPY_STATUS2_FLEXRAY_NO_HEADERCRC
SPY_STATUS2_CAN_ISO15765_LOGICAL_FRAME = _VSBIOFlags.SPY_STATUS2_CAN_ISO15765_LOGICAL_FRAME
SPY_STATUS2_CAN_HAVE_LINK_DATA = _VSBIOFlags.SPY_STATUS2_CAN_HAVE_LINK_DATA
SPY_STATUS3_CANFD_ESI = _VSBIOFlags.SPY_STATUS3_CANFD_ESI
SPY_STATUS3_CANFD_IDE = _VSBIOFlags.SPY_STATUS3_CANFD_IDE
SPY_STATUS3_CANFD_RTR = _VSBIOFlags.SPY_STATUS3_CANFD_RTR
SPY_STATUS3_CANFD_FDF = _VSBIOFlags.SPY_STATUS3_CANFD_FDF
SPY_STATUS3_CANFD_BRS = _VSBIOFlags.SPY_STATUS3_CANFD_BRS
NEO_CFG_MPIC_HS_CAN_CNF1 = _VSBIOFlags.NEO_CFG_MPIC_HS_CAN_CNF1
NEO_CFG_MPIC_HS_CAN_CNF2 = _VSBIOFlags.NEO_CFG_MPIC_HS_CAN_CNF2
NEO_CFG_MPIC_HS_CAN_CNF3 = _VSBIOFlags.NEO_CFG_MPIC_HS_CAN_CNF3
NEO_CFG_MPIC_HS_CAN_MODE = _VSBIOFlags.NEO_CFG_MPIC_HS_CAN_MODE
NEO_CFG_MPIC_MS_CAN_CNF1 = _VSBIOFlags.NEO_CFG_MPIC_MS_CAN_CNF1
NEO_CFG_MPIC_MS_CAN_CNF2 = _VSBIOFlags.NEO_CFG_MPIC_MS_CAN_CNF2
NEO_CFG_MPIC_MS_CAN_CNF3 = _VSBIOFlags.NEO_CFG_MPIC_MS_CAN_CNF3
NEO_CFG_MPIC_SW_CAN_CNF1 = _VSBIOFlags.NEO_CFG_MPIC_SW_CAN_CNF1
NEO_CFG_MPIC_SW_CAN_CNF2 = _VSBIOFlags.NEO_CFG_MPIC_SW_CAN_CNF2
NEO_CFG_MPIC_SW_CAN_CNF3 = _VSBIOFlags.NEO_CFG_MPIC_SW_CAN_CNF3
NEO_CFG_MPIC_LSFT_CAN_CNF1 = _VSBIOFlags.NEO_CFG_MPIC_LSFT_CAN_CNF1
NEO_CFG_MPIC_LSFT_CAN_CNF2 = _VSBIOFlags.NEO_CFG_MPIC_LSFT_CAN_CNF2
NEO_CFG_MPIC_LSFT_CAN_CNF3 = _VSBIOFlags.NEO_CFG_MPIC_LSFT_CAN_CNF3
NEOVI_TIMESTAMP_2 = _VSBIOFlags.NEOVI_TIMESTAMP_2
NEOVI_TIMESTAMP_1 = _VSBIOFlags.NEOVI_TIMESTAMP_1
NEOVIPRO_VCAN_TIMESTAMP_2 = _VSBIOFlags.NEOVIPRO_VCAN_TIMESTAMP_2
NEOVIPRO_VCAN_TIMESTAMP_1 = _VSBIOFlags.NEOVIPRO_VCAN_TIMESTAMP_1
NEOVI6_VCAN_TIMESTAMP_2 = _VSBIOFlags.NEOVI6_VCAN_TIMESTAMP_2
NEOVI6_VCAN_TIMESTAMP_1 = _VSBIOFlags.NEOVI6_VCAN_TIMESTAMP_1
NEOVI_RED_TIMESTAMP_2_25NS = _VSBIOFlags.NEOVI_RED_TIMESTAMP_2_25NS
NEOVI_RED_TIMESTAMP_1_25NS = _VSBIOFlags.NEOVI_RED_TIMESTAMP_1_25NS
NEOVI_RED_TIMESTAMP_2_10NS = _VSBIOFlags.NEOVI_RED_TIMESTAMP_2_10NS
NEOVI_RED_TIMESTAMP_1_10NS = _VSBIOFlags.NEOVI_RED_TIMESTAMP_1_10NS
NEOVI_RED_TIMESTAMP_2_10US = _VSBIOFlags.NEOVI_RED_TIMESTAMP_2_10US
NEOVI_RED_TIMESTAMP_1_10US = _VSBIOFlags.NEOVI_RED_TIMESTAMP_1_10US
NEOVIPRO_VCAN_TIMESTAMP_2_US = _VSBIOFlags.NEOVIPRO_VCAN_TIMESTAMP_2_US
NEOVIPRO_VCAN_TIMESTAMP_1_US = _VSBIOFlags.NEOVIPRO_VCAN_TIMESTAMP_1_US
# This file is compatible with both classic and new-style classes.





from ICS_VSBIO  import VSBIOInterface as vsb
import os 

class VSBWriter:
    def __init__(self, filename):
        if not os.path.isabs(filename):
            filename = os.path.realpath(filename)
        self.handle = vsb.WriteVSB(filename)

    def __del__(self):
        vsb.WriteClose(self.handle)

    def write_msg(self, vsbMessage):
        ''' writes vsb message to file.'''
        vsb.WriteMessage(self.handle, vsbMessage.info, vsbMessage.sizeOfMsg)



from distutils.command.build import build
from setuptools.command.install import install
from distutils.core import setup, Extension
import distutils 
import platform

version = '0.0.4.6'

def which(program):
    import os
    def is_exe(fpath):
        return os.path.isfile(fpath) and os.access(fpath, os.X_OK)

    fpath, fname = os.path.split(program)
    if fpath:
        if is_exe(program):
            return program
    else:
        for path in os.environ["PATH"].split(os.pathsep):
            exe_file = os.path.join(path, program)
            if is_exe(exe_file):
                return exe_file

    return None

class CustomBuild(build):
	def run(self):
		self.run_command('build_ext')
		build.run(self)


class CustomInstall(install):
	def run(self):
		self.run_command('build_ext')
		self.do_egg_install()


if platform.system() == 'Windows':
	define_macros = [('_WIN32', None), ('VSBIODLL_EXPORTS', None)]
elif platform.system() == 'Linux': 
	define_macros = [('LINUXSO', None)]
define_macros += [('PYD', None)]

if which('swig') or which('swig.exe') :
	swig_opts = ['-c++', '-py3']
	flags_sources=['ICS_VSBIO/VSBIOFlags.i']
	interface_sources=['ICS_VSBIO/StandardLibrary/src/OFile.cpp',
		'ICS_VSBIO/VSBIO/src/VSBIO.cpp',
		'ICS_VSBIO/VSBIO/src/MessageTimeDecoderVSB.cpp',
		'ICS_VSBIO/VSBIODLL.cpp',
		'ICS_VSBIO/VSBIOInterface.i',
		'ICS_VSBIO/VSBIOFlags.i']
else:
	swig_opts = None
	flags_sources=['ICS_VSBIO/VSBIOFlags_wrap.cpp']
	interface_sources=['ICS_VSBIO/StandardLibrary/src/OFile.cpp',
		'ICS_VSBIO/VSBIO/src/VSBIO.cpp',
		'ICS_VSBIO/VSBIO/src/MessageTimeDecoderVSB.cpp',
		'ICS_VSBIO/VSBIODLL.cpp',
		'ICS_VSBIO/VSBIOInterface_wrap.cpp',
		'ICS_VSBIO/VSBIOFlags_wrap.cpp']

if swig_opts is not None:
	for define, value in define_macros:
		swig_opts.append("-D" + define)	

VSBIOInterface = Extension('_VSBIOInterface',
				sources=interface_sources,
				swig_opts=swig_opts,
				include_dirs=['ICS_VSBIO/VSBIO/include', 'ICS_VSBIO/StandardLibrary/include', 'ICS_VSBIO/Hardware/include', 'ICS_VSBIO/Core/include'],
				define_macros= define_macros)

VSBIOFlags = Extension('_VSBIOFlags',
				sources=flags_sources,
				swig_opts=swig_opts,
				include_dirs=['ICS_VSBIO/VSBIO/include', 'ICS_VSBIO/StandardLibrary/include', 'ICS_VSBIO/Hardware/include', 'ICS_VSBIO/Core/include'],
				define_macros= define_macros)

setup(  name            = 'ICS_VSBIO',
		version         = version,
		author          = 'Zaid Nackasha',
		author_email    = 'znackasha@intrepidcs.com',
		description     = 'Python package to help users read and write Intrepid\'s vsb files',
		url             = 'https://github.com/intrepidcs/ICS_VSBIO',
		download_url 	= 'https://github.com/intrepidcs/ICS_VSBIO/archive/' + version + '.tar.gz',
		platforms       = ['x86_64'],
		packages        = ['ICS_VSBIO'],
		package_dir     = {'ICS_VSBIO': 'ICS_VSBIO'},
		cmdclass		= {'build': CustomBuild, 'install': CustomInstall},
		ext_modules     = [VSBIOInterface, VSBIOFlags],
		py_modules		= ['VSBIOInterface', 'VSBIOFlags'] )



from ICS_VSBIO import VSBIOInterface as vsb

import os

class ReadStatus:
	eSuccess = vsb.eSuccess
	eEndOfFile = vsb.eEndOfFile
	eError = vsb.eError
	eBufferToSmall = vsb.eBufferToSmall
	eFileOpened = 10
	eInit = 11

class VSBMessage:
	def __init__(self, Msg, EDP, sizeOfMsg):
		self.info = Msg
		self.exData = EDP
		self.sizeOfMsg = sizeOfMsg

	def get_byte_from_data(self, index):
		if index > self.sizeOfMsg:
			raise ValueError("index greater then size")
		return vsb.GetByteFromData(self.info, index)

class VSBReader:
	def __init__(self, filename):
		self.size = 64
		self.state = ReadStatus.eInit
		self.__fileOpen(filename)

	def __fileOpen(self, filename):
		self.filename = filename
		self.message = vsb.VSBIOMalloc(self.size)
		if not os.path.isabs(filename):
			filename = os.path.realpath(filename)
		self.handle = vsb.ReadVSB(filename)
		self.state = ReadStatus.eFileOpened
 
	def __del__(self):
		vsb.VSBIOFree(self.message)
		if self.state != vsb.eEndOfFile :
			vsb.ReadClose(self.handle)

	def __iter__(self):
		if self.state == ReadStatus.eInit:
			raise 
		elif self.state == ReadStatus.eEndOfFile:
			self.__fileOpen(self.filename)
			if self.state != ReadStatus.eFileOpened:
				raise
		elif self.state == ReadStatus.eError:
			vsb.ReadClose(self.handle)
			self.__fileOpen(self.filename)
			if self.state != ReadStatus.eFileOpened:
				raise
		return self

	def __next__(self):
		"""  get next message from the buffer.  """
		self.state, size = vsb.ReadNextMessage(self.handle, self.message, self.size)
		if self.state == vsb.eSuccess:
			return VSBMessage(self.message, vsb.GetEDP(self.message), size)
		elif self.state == vsb.eEndOfFile:
			vsb.ReadClose(self.handle)
			raise StopIteration()
		elif self.state == vsb.eError:
			raise ValueError(self.get_error_message())
		elif self.state == vsb.eBufferToSmall:
			vsb.VSBIOFree(self.message)
			self.message = vsb.VSBIOMalloc(size)
			self.size = size
			return self.__next__()

	def get_progress(self):
		'''
		returns the progress as a integer percentage
		'''
		return vsb.GetProgress(self.handle)

	def get_error_message(self):
		'''
		return Error messages if any.
		'''
		return vsb.GetErrorMessage(self.handle)

	def get_display_message(self):
		'''
		return Display messages if any
		'''
		return vsb.GetDisplayMessage(self.handle)

	def get_status(self):
		'''
		returns the current state
		'''
		return self.state

	def get_status_as_string(self):
		'''
		returns the current state in string format
		'''
		if self.state == ReadStatus.eSuccess:
			return 'Messages read successfully'
		elif self.state == ReadStatus.eError:
			return 'Error'
		elif self.state == ReadStatus.eEndOfFile:
			return 'End Of File'
		elif self.state == ReadStatus.eFileOpened:
			return 'File Opened'
		elif self.state == ReadStature.eInit:
			return 'Init'
